@@ -1235,6 +1235,39 @@ class Room2D(_BaseGeometry):
 
         return tuple(intersected_rooms)
 
+    @staticmethod
+    def group_by_adjacency(rooms):
+        """Group Room2Ds together that are connected by adjacencies.
+
+        This is useful for separating rooms in the case where a Story contains
+        multiple towers or sections that are separated by outdoor boundary conditions.
+
+        Args:
+            rooms: A list of Room2Ds to be grouped by their adjacency.
+
+        Returns:
+            A list of list with each sub-list containing rooms that share adjacencies.
+        """
+        return Room2D._adjacency_grouping(rooms, Room2D._find_adjacent_rooms)
+
+    @staticmethod
+    def group_by_air_boundary_adjacency(rooms):
+        """Group Room2Ds together that share air boundaries.
+
+        This is useful for understanding the radiant enclosures that will exist
+        when a model is exported to EnergyPlus.
+
+        Args:
+            rooms: A list of Room2Ds to be grouped by their air boundary adjacency.
+
+        Returns:
+            A list of list with each sub-list containing Room2Ds that share adjacent
+            air boundaries. If a Room has no air boundaries it will the the only
+            item within its sub-list.
+        """
+        return Room2D._adjacency_grouping(
+            rooms, Room2D._find_adjacent_air_boundary_rooms)
+
     @staticmethod
     def floor_segment_by_index(geometry, segment_index):
         """Get a particular LineSegment3D from a Face3D object.
@@ -1618,6 +1651,70 @@ class Room2D(_BaseGeometry):
                             if p2.is_equivalent(v2, tolerance):
                                 return face
 
+    @staticmethod
+    def _adjacency_grouping(rooms, adj_finding_function):
+        """Group Room2Ds together according to an adjacency finding function.
+
+        Args:
+            rooms: A list of Room2Ds to be grouped by their adjacency.
+            adj_finding_function: A function that denotes which rooms are adjacent
+                to another.
+
+        Returns:
+            A list of list with each sub-list containing rooms that share adjacencies.
+        """
+        # create a room lookup table and duplicate the list of rooms
+        room_lookup = {rm.identifier: rm for rm in rooms}
+        all_rooms = list(rooms)
+        adj_network = []
+
+        # loop through the rooms and find air boundary adjacencies
+        for room in all_rooms:
+            adj_ids = adj_finding_function(room)
+            if len(adj_ids) == 0:  # a room that is its own solar enclosure
+                adj_network.append([room])
+            else:  # there are other adjacent rooms to find
+                local_network = [room]
+                local_ids, first_id = set(adj_ids), room.identifier
+                while len(adj_ids) != 0:
+                    # add the current rooms to the local network
+                    adj_objs = [room_lookup[rm_id] for rm_id in adj_ids]
+                    local_network.extend(adj_objs)
+                    adj_ids = []  # reset the list of new adjacencies
+                    # find any rooms that are adjacent to the adjacent rooms
+                    for obj in adj_objs:
+                        all_new_ids = adj_finding_function(obj)
+                        new_ids = [rid for rid in all_new_ids
+                                   if rid not in local_ids and rid != first_id]
+                        for rm_id in new_ids:
+                            local_ids.add(rm_id)
+                        adj_ids.extend(new_ids)
+                # after the local network is understood, clean up duplicated rooms
+                adj_network.append(local_network)
+                i_to_remove = [i for i, room_obj in enumerate(all_rooms)
+                               if room_obj.identifier in local_ids]
+                for i in reversed(i_to_remove):
+                    all_rooms.pop(i)
+        return adj_network
+
+    @staticmethod
+    def _find_adjacent_rooms(room):
+        """Find the identifiers of all rooms with adjacency to a room."""
+        adj_rooms = []
+        for bc in room._boundary_conditions:
+            if isinstance(bc, Surface):
+                adj_rooms.append(bc.boundary_condition_objects[-1])
+        return adj_rooms
+
+    @staticmethod
+    def _find_adjacent_air_boundary_rooms(room):
+        """Find the identifiers of all rooms with air boundary adjacency to a room."""
+        adj_rooms = []
+        for bc, ab in zip(room._boundary_conditions, room.air_boundaries):
+            if ab and isinstance(bc, Surface):
+                adj_rooms.append(bc.boundary_condition_objects[-1])
+        return adj_rooms
+
     def __copy__(self):
         new_r = Room2D(self.identifier, self._floor_geometry,
                        self.floor_to_ceiling_height,
